<template>
    <el-cascader
        v-model="value"
        :options="options"
        :show-all-levels="false"
        size="small"
        clearable
        :props="{
            expandTrigger: 'hover',
            checkStrictly: true,
            value: 'id',
            label: 'name',
            children: 'chirldren',
        }"
        style="width: 200px"
        ref="cascader"
        @change="handleCascaderChange"
    ></el-cascader>
</template>

<script>
export default {
    props: {
        placeholder: {
            type: String,
            default: '请选择',
        },
        companyId: {
            type: Array,
            default: () => ['1419863231459102720'],
        },
    },
    data() {
        return {
            options: [], // orgData.list,
            value: ['1419863231459102720'],
            companyIds: [],
            roadSegmentId: '',
        }
    },
    watch: {
        companyId(newVal) {
            this.value = newVal
        },
    },
    created() {
        this.loadData()
    },
    methods: {
        loadData() {
            this.$http
                .get('${portal}/bizRoadSection/v1/roadTree')
                .then((res) => {
                    let data = (res && res.status == 200 && res.data) || []
                    this.deepSetChildren(data) // 设置路段的children为null
                    this.options = [
                        {
                            isDelete: '0',
                            id: '1419863231459102720',
                            name: '全国',
                            parentId: '0',
                            code: '10',
                            grade: '1',
                            orgKind: 'ogn',
                            demId: '1258608622670319616',
                            orderNo: 145,
                            isMaster: 0,
                            path: '1258608622670319616.1419863231459102720.',
                            pathName: '/中铁建昆仑投资集团',
                            limitNum: 0,
                            exceedLimitNum: 0,
                            disabled: false,
                            chirldren: data,
                        },
                    ]
                })
        },
        deepSetChildren(data) {
            data.forEach((i) => {
                let child = i.chirldren
                if (child && child.length !== 0) {
                    return this.deepSetChildren(child)
                } else {
                    i.chirldren = null
                }
            })
            return data
        },
        handleCascaderChange(val) {
            let result = []
            // 如果选中全国 那么就是查全部 不需要传参数
            if (val.length == 1) {
                result = ''
            } else if (val.length == 4) {
                let selectedList = this.$refs.cascader.getCheckedNodes()
                result = [selectedList[0].data.roadSegmentId]
            } else {
                let selectedList = this.$refs.cascader.getCheckedNodes()
                result = this.getChildNodeId(selectedList)
            }
            this.$emit('change', result)
        },
        getChildNodeId(data) {
            let result = []
            data.forEach((node) => {
                if (node.children && node.children.length !== 0) {
                    result = [...result, ...this.getChildNodeId(node.children)]
                } else {
                    result.push(node.data.roadSegmentId)
                }
            })
            return result
        },
    },
}
</script>

<style lang="scss">
.el-cascader-node__label {
    font-size: 16px;
}

</style>
